@@ -106,10 +106,11 @@ if __name__ == "__main__":
 
         run.shell = config["shell"]
         while True:
-            logmsg.info("Polling for jobs..")
+            interval = 40
+            logmsg.info("Polling for jobs.. ({} sec)".format(interval))
             job = run.poll()
             if not job:
-                time.sleep(10)
+                time.sleep(interval)
             else:
                 result = executor.run(run, job)
                 if result:
